@@ -11,8 +11,10 @@
 
 namespace Symfony\Component\HttpClient\Tests\DataCollector;
 
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\HttpClient\DataCollector\HttpClientDataCollector;
+use Symfony\Component\HttpClient\MockHttpClient;
 use Symfony\Component\HttpClient\NativeHttpClient;
 use Symfony\Component\HttpClient\TraceableHttpClient;
 use Symfony\Contracts\HttpClient\Test\TestHttpServer;
@@ -164,9 +166,7 @@ class HttpClientDataCollectorTest extends TestCase
         $this->assertEquals(0, $sut->getRequestCount());
     }
 
-    /**
-     * @dataProvider provideCurlRequests
-     */
+    #[DataProvider('provideCurlRequests')]
     public function testItGeneratesCurlCommandsAsExpected(array $request, string $expectedCurlCommand)
     {
         $sut = new HttpClientDataCollector();
@@ -177,7 +177,7 @@ class HttpClientDataCollectorTest extends TestCase
         $curlCommand = $collectedData['http_client']['traces'][0]['curlCommand'];
 
         $isWindows = '\\' === \DIRECTORY_SEPARATOR;
-        self::assertEquals(sprintf($expectedCurlCommand, $isWindows ? '"' : "'", $isWindows ? '' : "'"), $curlCommand);
+        self::assertEquals(\sprintf($expectedCurlCommand, $isWindows ? '"' : "'", $isWindows ? '' : "'"), $curlCommand);
     }
 
     public static function provideCurlRequests(): iterable
@@ -268,7 +268,7 @@ class HttpClientDataCollectorTest extends TestCase
                             'fooprop' => 'foopropval',
                             'barprop' => 'barpropval',
                         ],
-                        'tostring' => new class() {
+                        'tostring' => new class {
                             public function __toString(): string
                             {
                                 return 'tostringval';
@@ -358,7 +358,7 @@ class HttpClientDataCollectorTest extends TestCase
         $collectedData = $sut->getClients();
         self::assertCount(1, $collectedData['http_client']['traces']);
         $curlCommand = $collectedData['http_client']['traces'][0]['curlCommand'];
-        self::assertEquals(sprintf('curl \\
+        self::assertEquals(\sprintf('curl \\
   --compressed \\
   --request GET \\
   --url %1$shttp://localhost:8057/301%1$s \\
@@ -437,4 +437,42 @@ class HttpClientDataCollectorTest extends TestCase
 
         return $httpClient;
     }
+
+    #[DataProvider('provideClientIsResetWhenExpectedCases')]
+    public function testClientIsResetWhenExpected(\Closure $request, bool $wasReset)
+    {
+        $mockHttpClient = new class extends MockHttpClient {
+            public bool $wasReset = false;
+
+            public function reset(): void
+            {
+                parent::reset();
+
+                $this->wasReset = true;
+            }
+        };
+
+        $sut = new HttpClientDataCollector();
+        $sut->registerClient('http_client', $traceableHttpClient = new TraceableHttpClient($mockHttpClient));
+        $request($traceableHttpClient);
+        $sut->lateCollect();
+
+        $this->assertSame($wasReset, $mockHttpClient->wasReset);
+    }
+
+    public static function provideClientIsResetWhenExpectedCases(): iterable
+    {
+        yield [
+            function (TraceableHttpClient $traceableHttpClient) {
+                $response = $traceableHttpClient->request('GET', 'http://localhost/');
+                $response->getContent();
+            },
+            true,
+        ];
+
+        yield [
+            fn () => null,
+            false,
+        ];
+    }
 }
